@@ -54,14 +54,21 @@ modelsummary(mod, coef_omit = "^(?!.*ei|.*pt)")
     }
 
     # coef_rename
-    if (!is.null(coef_rename)) {
+    # TRUE: done in `get_estimates()` straight from the parameters() attribute
+    # FALSE: do nothing
+    if (!is.null(coef_rename) && !is.logical(coef_rename)) {
         if (is.character(coef_rename)) {
             dict <- coef_rename
         } else if (is.function(coef_rename)) {
             dict <- stats::setNames(coef_rename(estimates$term), estimates$term)
         }
         check_dups(dict)
-        estimates$term <- replace_dict(estimates$term, dict)
+        # if coef_rename is a function, then we trust the user to do interaction
+        # replacement. Otherwise, we can get duplicate replacements: "Height (in feet) (in feet)".
+        estimates$term <- replace_dict(
+            estimates$term,
+            dict,
+            interaction = !isTRUE(is.function(coef_rename)))
     }
 
     # coef_map
@@ -75,7 +82,10 @@ modelsummary(mod, coef_omit = "^(?!.*ei|.*pt)")
             stop("At least one of the term names in each model must appear in `coef_map`.")
         }
         estimates <- estimates[idx, , drop = FALSE]
-        estimates$term <- replace_dict(estimates$term, coef_map)
+        estimates$term <- replace_dict(
+            estimates$term,
+            coef_map,
+            interaction = !isTRUE(is.function(coef_rename)))
     }
 
     # group_map
@@ -84,7 +94,9 @@ modelsummary(mod, coef_omit = "^(?!.*ei|.*pt)")
             group_map <- stats::setNames(group_map, group_map)
         }
         estimates <- estimates[estimates$group %in% names(group_map), , drop = FALSE]
-        estimates$group <- replace_dict(estimates$group, group_map)
+        estimates$group <- replace_dict(
+            estimates$group,
+            group_map)
     }
 
     ## escape if needed
