@@ -1,7 +1,7 @@
 #' @include glance_custom.R
 #' @keywords internal
 glance_custom_internal.lm_robust <- function(x, vcov_type = NULL, ...) {
-    assert_dependency("estimatr")
+    insight::check_if_installed("estimatr")
     out <- data.frame(row.names = "firstrow")
     if (is.null(vcov_type) || !vcov_type %in% c("vector", "matrix", "function")) {
         if (x$clustered) {
